(function ($, Drupal) {
  Drupal.behaviors.mapbox = {
    attach: function (context, settings) {

      $('.mpbx').once('showMap').each(function () {

        let accessToken = settings.mpbx.accessToken,
          style = settings.mpbx.style,
          longitude = settings.mpbx.longitude,
          latitude = settings.mpbx.latitude,
          center = [longitude, latitude],
          zoom = settings.mpbx.zoom,
          markerUrl = settings.mpbx.marker,
          interactive = settings.mpbx.interactive,
          navigationEnabled = settings.mpbx.nav.enabled,
          navigationPosition = settings.mpbx.nav.position,
          navigationShowZoom = settings.mpbx.nav.zoom,
          navigationShowCompass = settings.mpbx.nav.compass,
          navigationVisualizePitch = settings.mpbx.nav.pitch,
          geolocationEnabled = settings.mpbx.geo.enabled,
          geolocationPosition = settings.mpbx.geo.position,
          geolocationEnableHighAccuracy = settings.mpbx.geo.accuracy,
          geolocationTrackUserLocation = settings.mpbx.geo.track,
          geolocationShowUserLocation = settings.mpbx.geo.show,
          geolocationShowAccuracyCircle = settings.mpbx.geo.circle,
          fullscreenEnabled = settings.mpbx.fullscreen.enabled,
          fullscreenPosition = settings.mpbx.fullscreen.position;

        let container = 'map';

        mapboxgl.accessToken = accessToken;

        let map = new mapboxgl.Map({
          container: container,
          style: style,
          center: center,
          zoom: zoom,
          interactive: interactive,
        });

        if (markerUrl) {
          let marker = document.createElement('div'),
            markerInner = document.createElement('img');

          marker.className = 'marker';
          marker.style.width = '50px';
          marker.style.height = '50px';

          markerInner.src = markerUrl;

          marker.appendChild(markerInner);

          let options = {
            anchor: settings.mpbx.anchor,
          };

          new mapboxgl.Marker(marker, options)
            .setLngLat(center)
            .addTo(map);
        }

        if (navigationEnabled) {

          let navigationControl = new mapboxgl.NavigationControl({
            showZoom: navigationShowZoom,
            showCompass: navigationShowCompass,
            visualizePitch: navigationVisualizePitch,
          });

          map.addControl(navigationControl, navigationPosition);
        }

        if (geolocationEnabled) {

          let geolocationControl = new mapboxgl.GeolocateControl({
            positionOptions: {
              enableHighAccuracy: geolocationEnableHighAccuracy,
            },
            trackUserLocation: geolocationTrackUserLocation,
            showUserLocation: geolocationShowUserLocation,
            showAccuracyCircle: geolocationShowAccuracyCircle,
          });

          map.addControl(geolocationControl, geolocationPosition);
        }

        if (fullscreenEnabled) {

          let fullscreenControl = new mapboxgl.FullscreenControl();

          map.addControl(fullscreenControl, fullscreenPosition);
        }

      });

    },
  };
})(jQuery, Drupal)
