<?php

namespace Drupal\mpbx\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a MapBox block.
 *
 * @Block(
 *   id = "mpbx_block",
 *   admin_label = @Translation("MapBox"),
 * )
 */
class MpbxBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('mpbx.settings');
    return [
      '#title' => $this->t('MapBox'),
      '#description' => $this->t('MapBox block'),
      '#theme' => 'mpbx',
      '#attached' => [
        'drupalSettings' => [
          'mpbx' => [
            'accessToken' => $config->get('access_token'),
            'style' => $config->get('style'),
            'latitude' => $config->get('coordinates.lat'),
            'longitude' => $config->get('coordinates.lon'),
            'zoom' => $config->get('zoom'),
            'marker' => $config->get('marker.url'),
            'anchor' => $config->get('anchor'),
            'interactive' => $config->get('interactive'),
            'nav' => [
              'enabled' => $config->get('nav.enabled'),
              'position' => $config->get('nav.position'),
              'zoom' => $config->get('nav.zoom'),
              'compass' => $config->get('nav.compass'),
              'pitch' => $config->get('nav.pitch'),
            ],
            'geo' => [
              'enabled' => $config->get('geo.enabled'),
              'position' => $config->get('geo.position'),
              'accuracy' => $config->get('geo.accuracy'),
              'track' => $config->get('geo.track'),
              'show' => $config->get('geo.show'),
              'circle' => $config->get('geo.circle'),
            ],
            'fullscreen' => [
              'enabled' => $config->get('fullscreen.enabled'),
              'position' => $config->get('fullscreen.position'),
            ],
          ],
        ],
      ],
      '#contextual_links' => [
        'mpbx' => [
          'route_parameters' => [],
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
  }

}
